/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var SelectFile = function()
{
	var selectFile = {};
	var defaultFilename;
	
	selectFile.initPage = function()
	{
		defaultFilename = Data.get('page-data', 'default-filename');

		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnOk', selectFile.returnSelected);
	}

	// Called when a user selects a file
	// Update the full path and switch the
	// default filename to the current filename
	selectFile.setSelectedFile = function(fileId, path)
	{
		var frm = document.forms['file'];
		var i = path.lastIndexOf('/');
		if (i >= 0) defaultFilename = path.substring(i+1);
		frm.file_id.value = fileId;
		frm.path.value = path;
	}

	// Called when a user selects a directory
	// If a default filename exists, append that to the directory
	// path to create the full filename
	selectFile.setSelectedDirectory = function(directoryId, path)
	{
		var frm = document.forms['file'];
		if (defaultFilename)
		{
			if (path.substring(path.length-1) != '/') path += '/';
			path += defaultFilename;
		}
		frm.file_id.value = '';
		frm.path.value = path;
	}

	selectFile.returnSelected = function()
	{
		var frm = document.forms['file'];
		
		if (frm.path.value)
		{
			var callback = Data.get('page-data', 'callback');
			var notifyTarget = window.opener.document.getElementById(callback);
			var callbackMethod = window.opener[callback];
			if (notifyTarget)
			{
				// Send event to the target in the opener window
				Events.sendCustomEvent(notifyTarget, 'base-selected', {'path': frm.path.value});
			}
			else if (callbackMethod)
			{
				// Call the callback method in the opener window
				callbackMethod.call(null, frm.path.value);
			}
		}
		window.close();
	}

	return selectFile;
}();

Doc.onLoad(SelectFile.initPage);


