/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var PlateEvents = function()
{
	var plateEvents = {};
	
	/**
		Initialize the page.
	*/
	plateEvents.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', plateEvents.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', plateEvents.validateEvent);

			// Protocol
			Buttons.addClickHandler('protocol_id.select', plateEvents.selectProtocol);
			Events.addEventHandler('protocol_id', 'base-selected', Items.onItemSelected);
			
			// Hardware
			Buttons.addClickHandler('hardware_id.select', plateEvents.selectHardware);
			Events.addEventHandler('hardware_id', 'base-selected', Items.onItemSelected);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var plateId = Data.get('page-data', 'plate-id');
			var attributes = {'item-type': 'PLATEEVENT', 'item-id': itemId, 'extra-url': '&plate_id='+plateId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'PLATEEVENT'};
			var tableAttributes = {'table-id': 'events'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			TabControl.setSwitchFunction('main', plateEvents.switchTab);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	plateEvents.switchTab = function(event)
	{
		var target = event.target;
		var tabId = target.id.substring(5);
		var frm = document.forms['events'];
		var plateId = frm.plate_id.value;

		var url;
		if (tabId == 'wells')
		{
			url = '../wells/index.jsp?ID='+App.getSessionId();
			url += '&plate_id='+plateId;
		}
		else
		{
			url = '../index.jsp?ID='+App.getSessionId();
			url += '&cmd=ViewItem&item_id='+plateId;
			url += '&tab='+tabId;
		}
		location.replace(url);
	}


	plateEvents.validateEvent = function()
	{
		return true;
	}

	// Submit the form
	plateEvents.save = function()
	{
		var frm = document.forms['event'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}

	plateEvents.selectHardware = function()
	{
		var frm = document.forms['event'];
		var url = '';
		if (frm.hardware_id.length > 1)
		{
			var id = Math.abs(parseInt(frm.hardware_id[1].value));
			url += '&item_id='+id;
		}
		Dialogs.selectItem('HARDWARE', 'hardware_id', 0, url);
	}
	
	plateEvents.selectProtocol = function()
	{
		var frm = document.forms['event'];
		var url = '';
		if (frm.protocol_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.protocol_id[1].value));				
			url += '&item_id='+id;
		}
		
		var protocolTypeId;
		if (frm.plateeventtype_id)
		{
			protocolTypeId = Data.int(frm.plateeventtype_id[frm.plateeventtype_id.selectedIndex], 'protocol-type');
		}
		else 
		{
			protocolTypeId = Data.int('page-data', 'protocol-type');
			
		}
		if (protocolTypeId)
		{
			url += '&resetTemporary=1&tmpfilter:INT:itemSubtype='+protocolTypeId;
		}
		Dialogs.selectItem('PROTOCOL', 'protocol_id', 0, url);
	}
	
	return plateEvents;
}();

Doc.onLoad(PlateEvents.initPage);
