<%-- $Id: index.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	$Id: index.jsp 7954 2021-05-12 13:27:22Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.BasicItem"
	import="net.sf.basedb.core.SharedItem"
	import="net.sf.basedb.core.OwnedItem"
	import="net.sf.basedb.core.Ownable"
	import="net.sf.basedb.core.Removable"
	import="net.sf.basedb.core.MultiPermissions"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.ItemAlreadyExistsException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.util.HTML"
	import="java.util.Enumeration"
	import="java.util.Set"
	import="java.util.HashSet"
	import="java.util.List"
	import="java.util.ArrayList"
	import="java.util.Collections"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%!
	private static final ItemContext defaultContext = Base.createDefaultContext("", "type,name");
	private static final Item itemType = Item.PROJECT;
	private static final String subContext = "items";
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";
final int projectId = Values.getInt(request.getParameter("project_id"));

final String listPage = "list_items.jsp?ID="+ID+"&project_id="+projectId;

String forward = null;
String redirect = null;
String message = null;
DbControl dc = null;

try
{
	if (cmd == null || "List".equals(cmd))
	{
		// Display the list page without updatinging the current context
		Base.getAndSetCurrentContext(sc, itemType, subContext, null, defaultContext);
		redirect = listPage;
	}
	else if ("UpdateContext".equals(cmd))
	{
		// Display the list page after updating the current context from the request parameters
		Base.getAndSetCurrentContext(sc, itemType, subContext, pageContext, defaultContext);
		redirect = listPage;
	}
	else if ("LoadContext".equals(cmd))
	{
		// Display the list page after loading a saved context
		int contextId = Values.getInt(request.getParameter("context"));
		Base.loadContext(sc, contextId, defaultContext);
		redirect = listPage;
	}

	else if ("DeleteItems".equals(cmd))
	{
		// Delete all selected items on the list page
		dc = sc.newDbControl(":Delete items in project");
		int numTotal = 0;
		int numRemoved = 0;

		Enumeration<String> names = request.getParameterNames();
		while (names.hasMoreElements())
		{
			String name = names.nextElement();
			if (name.startsWith("item:"))
			{
				Item itemType = Item.valueOf(name.substring(5));
				Integer[] ids = Values.getInt(request.getParameterValues(name));
				for (int itemId : ids)
				{
					numTotal++;
					BasicItem item = itemType.getById(dc, itemId);
					if (item instanceof Removable && item.hasPermission(Permission.DELETE))
					{
						((Removable)item).setRemoved(true);
						numRemoved++;
					}
				}
			}
		}
		dc.commit();

		if (numTotal != numRemoved)
		{
			message = (numRemoved == 0 ? "No" : "Only "+numRemoved+" of "+numTotal) + " items could be deleted, because you have no DELETE permission";
		}
		redirect = listPage;
	}
	else if ("RestoreItems".equals(cmd))
	{
		// Restore all selected items on the list page
		dc = sc.newDbControl(":Restore items in project");
		int numTotal = 0;
		int numRemoved = 0;

		Enumeration<String> names = request.getParameterNames();
		while (names.hasMoreElements())
		{
			String name = names.nextElement();
			if (name.startsWith("item:"))
			{
				Item itemType = Item.valueOf(name.substring(5));
				Integer[] ids = Values.getInt(request.getParameterValues(name));
				for (int itemId : ids)
				{
					numTotal++;
					BasicItem item = itemType.getById(dc, itemId);
					if (item instanceof Removable && item.hasPermission(Permission.WRITE))
					{
						((Removable)item).setRemoved(false);
						numRemoved++;
					}
				}
			}
		}
		dc.commit();

		if (numTotal != numRemoved)
		{
			message = (numRemoved == 0 ? "No" : "Only "+numRemoved+" of "+numTotal) + " items could be restored, because you have no WRITE permission";
		}
		redirect = listPage;
	}
	else if ("ShareItems".equals(cmd))
	{
		// Share all selected items on the list page
		dc = sc.newDbControl(":Share items in project");
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, subContext, pageContext, defaultContext);

		Set<SharedItem> ss = new HashSet<SharedItem>();
		Enumeration<String> names = request.getParameterNames();
		while (names.hasMoreElements())
		{
			String name = names.nextElement();
			if (name.startsWith("item:"))
			{
				Item itemType = Item.valueOf(name.substring(5));
				Integer[] ids = Values.getInt(request.getParameterValues(name));
				for (int itemId : ids)
				{
					ss.add((SharedItem)itemType.getById(dc, itemId));
				}
			}
		}
		cc.setObject("MultiPermissions", new MultiPermissions(ss));
		dc.close();
		redirect = "../../../common/share/share.jsp?ID="+ID+"&item_type="+itemType.name()+"&subcontext="+subContext;
	}
	else if ("SetOwnerOfItems".equals(cmd))
	{
		// Change owner of items selected on a list page
		dc = sc.newDbControl(":Set owner of item in project");
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		Set<OwnedItem> items = new HashSet<OwnedItem>();
		Enumeration<String> names = request.getParameterNames();
		//User user = User.getById(dc, sc.getLoggedInUserId());
		while (names.hasMoreElements())
		{
			String name = names.nextElement();
			if (name.startsWith("item:"))
			{
				Item itemType = Item.valueOf(name.substring(5));
				Integer[] ids = Values.getInt(request.getParameterValues(name));
				for (int itemId : ids)
				{
					BasicItem item = itemType.getById(dc, itemId);
					if (item instanceof OwnedItem && item.hasPermission(Permission.SET_OWNER))
					{
						items.add((OwnedItem)item);
					}
				}
			}
		}
		dc.close();
		cc.setObject("OwnedItems", items);
		redirect = "../../../common/ownership/ownership.jsp?ID="+ID+"&item_type="+itemType.name();
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
}
finally
{
	if (dc != null) dc.close();
}

if (forward != null)
{
	sc.setSessionSetting("alert-message", message);
	pageContext.forward(forward);
}
else if (redirect != null)
{
	sc.setSessionSetting("alert-message", message);
	response.sendRedirect(redirect);
}
else if (message == null)
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&wait=0");
}
else
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&message="+HTML.urlEncode(message));
}
%>

